import * as i0 from '@angular/core';
import { forwardRef, Component, Input, NgModule, HostListener, Inject, ViewChild, Directive, Renderer2 } from '@angular/core';
import * as i4 from '@ngx-translate/core';
import { TranslateModule, TranslateService } from '@ngx-translate/core';
import { NarikAutoComplete, NarikButton, BUTTON_DEFAULT_OPTIONS, NarikCheckBox, NarikCheckBoxList, NarikDataTable, NarikDatePicker, NarikInput, NarikRadioGroup, NarikSelect, NarikDynamicForm, NarikTreeview, NarikToolBar, NarikTabOutlet } from '@narik/ui-core';
import * as i2 from '@angular/forms';
import { NG_VALUE_ACCESSOR, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { debounceTime, distinctUntilChanged, map, tap, switchMap, finalize, take } from 'rxjs/operators';
import { of } from 'rxjs';
import { DataProviderService, MODULE_DATA_KEY, PARAMETERS, DIALOG_CONTAINER, DIALOG_MESSAGE_COMPONENT, DIALOG_INPUT_COMPONENT } from '@narik/infrastructure';
import * as i1 from '@angular/common';
import { CommonModule, DOCUMENT } from '@angular/common';
import * as i1$1 from '@ng-bootstrap/ng-bootstrap';
import { NgbTypeaheadModule, NgbTooltipModule, NgbDatepickerModule, NgbDateAdapter, NgbDateNativeAdapter, NgbNavModule } from '@ng-bootstrap/ng-bootstrap';
import { BusyIndicator, NarikListForm, NarikEditForm } from '@narik/app-core';
import * as i9 from '@narik/common';
import { NarikCommonModule, groupBy } from '@narik/common';
import { __decorate, __metadata } from 'tslib';
import { NarikInject, NarikDialogContainer, DialogAnimationBody } from '@narik/core';
import * as i8 from '@angular/flex-layout/flex';
import { FlexLayoutModule } from '@angular/flex-layout';
import { trigger } from '@angular/animations';
import { UUID } from 'angular2-uuid';

const NARIK_UI_COMPONENT_INPUTS = ['options'];
const NARIK_UI_FORM_INPUTS = [
    'id',
    'name',
    'label',
    'disabled',
    'required',
    'readOnly',
    'placeHolder',
    ...NARIK_UI_COMPONENT_INPUTS,
];
const NARIK_DATA_ORIENTED_OUTPUTS = [
    'dataChange',
    'selectedItemChange',
];
const NARIK_DATA_ORIENTED_INPUTS = [
    'listenForDataChange',
    'dataSource',
    'dataKey',
    'dataUrl',
    'dataInfo',
    'dataProviderKey',
    'dataParameters',
    'moduleKey',
    'dataMethod',
    'dataUrlMethod',
    ...NARIK_UI_FORM_INPUTS,
];
const NARIK_DATA_DISPLAY_VALUE_OUTPUTS = [
    ...NARIK_DATA_ORIENTED_OUTPUTS,
];
const NARIK_DATA_DISPLAY_VALUE_INPUTS = [
    'displayField',
    'valueField',
    ...NARIK_DATA_ORIENTED_INPUTS,
];
const NARIK_AUTOCOMPLETE_INPUTS = [
    'displayText',
    'minSearchLength',
    'isLazyLoadData',
];
const NARIK_CHECKBOX_INPUTS = ['tag', ...NARIK_UI_FORM_INPUTS];
const NARIK_SELECT_INPUTS = ['multiple'];
const NARIK_DATA_TABLE_SELECT_INPUTS = [
    ...NARIK_SELECT_INPUTS,
    'gridOptions',
];
const NARIK_DATE_PICKER_INPUTS = [...NARIK_UI_FORM_INPUTS];
const NARIK_INPUT_INPUTS = [
    'maxlength',
    'type',
    'mask',
    'icon',
    'displayStatus',
    ...NARIK_UI_FORM_INPUTS,
];

class NarikNgbAutoComplete extends NarikAutoComplete {
    constructor(injector) {
        super(injector);
        this.internalChange = false;
        this.optionData = [];
    }
    set displayValue(value) {
        if (this._displayValue !== value) {
            if (!this.internalChange) {
                this.setValue(value);
            }
            this._displayValue = value;
        }
    }
    get displayValue() {
        return this._displayValue;
    }
    ngOnInit() {
        this.loadDataOnInit = !this.isLazyLoadData;
        super.ngOnInit();
        if (!this.isLazyLoadData) {
            this.search = (text$) => text$.pipe(debounceTime(200), distinctUntilChanged(), map((term) => term.length < this.minSearchLength
                ? []
                : this.optionData
                    .filter((v) => this.displayField
                    ? v[this.displayField]
                    : v
                        .toLowerCase()
                        .indexOf(term.toLowerCase()) >
                        -1)
                    .map((v) => this.displayField
                    ? v[this.displayField]
                    : v)
                    .slice(0, 10)));
        }
        else {
            const dataProviderService = this.injector.get(DataProviderService);
            const dataInfo = this.createDataInfo();
            dataInfo.dataMethod = 'POST';
            dataInfo.actionType = 'COMPLETE';
            if (!dataInfo.moduleKey) {
                dataInfo.moduleKey = this.injector.get(MODULE_DATA_KEY);
            }
            this.search = (text$) => text$.pipe(debounceTime(200), distinctUntilChanged(), tap((filter) => {
                if (filter && filter.length >= this.minSearchLength) {
                    this.dataIsLoading = true;
                }
            }), switchMap((filter) => {
                dataInfo.dataParameters = {
                    filter: filter,
                };
                return filter && filter.length >= this.minSearchLength
                    ? dataProviderService.getData(dataInfo).pipe(tap((result) => (this.optionData = result)), finalize(() => (this.dataIsLoading = false)))
                    : of([]);
            }));
        }
    }
    setValue(selectedText) {
        this.internalChange = true;
        if (!this.displayField) {
            this.value = selectedText;
        }
        else {
            if (selectedText) {
                const item = this.optionData.filter((x) => x[this.displayField] === selectedText)[0];
                if (item) {
                    this.value = item[this.valueField];
                }
                else {
                    this.value = undefined;
                }
            }
            else {
                this.value = undefined;
            }
        }
        this.internalChange = false;
    }
    useData(data) {
        this.optionData = data;
    }
    setDisplayText() {
        this.internalChange = true;
        if (this.value) {
            const item = this.optionData.filter((x) => x[this.valueField] === this.value)[0];
            this.displayValue = item
                ? item[this.displayField]
                : this.displayText;
        }
        else {
            this.displayValue = '';
        }
        this.internalChange = false;
    }
    valueChanged(newValue, oldValue) {
        if (newValue !== oldValue && !this.internalChange) {
            this.setDisplayText();
        }
    }
    onBlur() {
        if (!this.isLazyLoadData) {
            this.setDisplayText();
        }
    }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbAutoComplete.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbAutoComplete, deps: [{ token: i0.Injector }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbAutoComplete.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbAutoComplete, selector: "narik-ngb-autocomplete  , narik-autocomplete ", inputs: { displayField: "displayField", valueField: "valueField", listenForDataChange: "listenForDataChange", dataSource: "dataSource", dataKey: "dataKey", dataUrl: "dataUrl", dataInfo: "dataInfo", dataProviderKey: "dataProviderKey", dataParameters: "dataParameters", moduleKey: "moduleKey", dataMethod: "dataMethod", dataUrlMethod: "dataUrlMethod", id: "id", name: "name", label: "label", disabled: "disabled", required: "required", readOnly: "readOnly", placeHolder: "placeHolder", options: "options", icon: "icon" }, outputs: { dataChange: "dataChange", selectedItemChange: "selectedItemChange" }, providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef((() => NarikNgbAutoComplete)),
            multi: true,
        },
    ], usesInheritance: true, ngImport: i0, template: "<div class=\"form-group\">\n  <label for=\"{{id}}\">{{label}}</label>\n  <div class=\"input-group mb-3\" *ngIf=\"icon\">\n    <div class=\"input-group-prepend\">\n      <span class=\"input-group-text\"><i class=\"fa fa-{{icon}}\"></i></span>\n    </div>\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\n  </div>\n  <ng-container *ngIf=\"!icon\">\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\n  </ng-container>\n\n</div>\n<ng-template #inputElement>\n  <input (blur)=\"onBlur()\" [required]=\"required\" [(ngModel)]=\"displayValue\" [attr.disabled]=\"disabled || null\"\n    type=\"text\" name=\"{{name}}\" class=\"form-control\" [ngbTypeahead]=\"search\" id=\"{{id}}\" placeholder=\"{{placeHolder}}\">\n  <input type=\"hidden\" name=\"{{name}}\" [(ngModel)]=\"value\">\n</ng-template>", styles: [""], directives: [{ type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }, { type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { type: i1$1.NgbTypeahead, selector: "input[ngbTypeahead]", inputs: ["autocomplete", "placement", "container", "editable", "focusFirst", "showHint", "inputFormatter", "ngbTypeahead", "resultFormatter", "resultTemplate", "popupClass"], outputs: ["selectItem"], exportAs: ["ngbTypeahead"] }, { type: i2.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbAutoComplete, decorators: [{
            type: Component,
            args: [{ selector: 'narik-ngb-autocomplete  , narik-autocomplete ', inputs: [...NARIK_DATA_DISPLAY_VALUE_INPUTS], outputs: [...NARIK_DATA_DISPLAY_VALUE_OUTPUTS], providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef((() => NarikNgbAutoComplete)),
                            multi: true,
                        },
                    ], template: "<div class=\"form-group\">\n  <label for=\"{{id}}\">{{label}}</label>\n  <div class=\"input-group mb-3\" *ngIf=\"icon\">\n    <div class=\"input-group-prepend\">\n      <span class=\"input-group-text\"><i class=\"fa fa-{{icon}}\"></i></span>\n    </div>\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\n  </div>\n  <ng-container *ngIf=\"!icon\">\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\n  </ng-container>\n\n</div>\n<ng-template #inputElement>\n  <input (blur)=\"onBlur()\" [required]=\"required\" [(ngModel)]=\"displayValue\" [attr.disabled]=\"disabled || null\"\n    type=\"text\" name=\"{{name}}\" class=\"form-control\" [ngbTypeahead]=\"search\" id=\"{{id}}\" placeholder=\"{{placeHolder}}\">\n  <input type=\"hidden\" name=\"{{name}}\" [(ngModel)]=\"value\">\n</ng-template>", styles: [""] }]
        }], ctorParameters: function () { return [{ type: i0.Injector }]; }, propDecorators: { icon: [{
                type: Input
            }] } });

class NarikNgbAutoCompleteModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbAutoCompleteModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbAutoCompleteModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbAutoCompleteModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbAutoCompleteModule, declarations: [NarikNgbAutoComplete], imports: [CommonModule, FormsModule, NgbTypeaheadModule], exports: [NarikNgbAutoComplete] });
/** @nocollapse */ /** @nocollapse */ NarikNgbAutoCompleteModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbAutoCompleteModule, providers: [], imports: [[CommonModule, FormsModule, NgbTypeaheadModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbAutoCompleteModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, FormsModule, NgbTypeaheadModule],
                    declarations: [NarikNgbAutoComplete],
                    exports: [NarikNgbAutoComplete],
                    providers: [],
                }]
        }] });

class NarikNgbBusyIndicator {
    setBusy(newState, msg) {
        this.isBusy = newState;
    }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbBusyIndicator.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbBusyIndicator, deps: [], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbBusyIndicator.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbBusyIndicator, selector: "narik-ngb-busy-indicator , narik-busy-indicator", inputs: { isBusy: "isBusy" }, providers: [
        {
            provide: BusyIndicator,
            useExisting: forwardRef((() => NarikNgbBusyIndicator)),
        },
    ], ngImport: i0, template: "<ng-content></ng-content>\n<div class=\"loading-panel\" *ngIf=\"isBusy\"></div>\n<div *ngIf=\"isBusy\" id=\"loader-wrapper\">\n  <div class=\"spinner-border text-primary\" role=\"status\">\n    <span class=\"sr-only\">Loading...</span>\n  </div>\n</div>\n", styles: [".loading-panel{width:100%;position:absolute;top:0;left:0;bottom:0;right:0;background-color:#fff;opacity:.4;z-index:50000}#loader-wrapper{width:64px;height:64px;position:absolute;left:50%;top:50%;z-index:1000;margin-left:-20px;margin-top:-20px}\n"], directives: [{ type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbBusyIndicator, decorators: [{
            type: Component,
            args: [{ selector: 'narik-ngb-busy-indicator , narik-busy-indicator', providers: [
                        {
                            provide: BusyIndicator,
                            useExisting: forwardRef((() => NarikNgbBusyIndicator)),
                        },
                    ], template: "<ng-content></ng-content>\n<div class=\"loading-panel\" *ngIf=\"isBusy\"></div>\n<div *ngIf=\"isBusy\" id=\"loader-wrapper\">\n  <div class=\"spinner-border text-primary\" role=\"status\">\n    <span class=\"sr-only\">Loading...</span>\n  </div>\n</div>\n", styles: [".loading-panel{width:100%;position:absolute;top:0;left:0;bottom:0;right:0;background-color:#fff;opacity:.4;z-index:50000}#loader-wrapper{width:64px;height:64px;position:absolute;left:50%;top:50%;z-index:1000;margin-left:-20px;margin-top:-20px}\n"] }]
        }], propDecorators: { isBusy: [{
                type: Input
            }] } });

class NarikNgbBusyIndicatorModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbBusyIndicatorModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbBusyIndicatorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbBusyIndicatorModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbBusyIndicatorModule, declarations: [NarikNgbBusyIndicator], imports: [CommonModule, TranslateModule], exports: [NarikNgbBusyIndicator] });
/** @nocollapse */ /** @nocollapse */ NarikNgbBusyIndicatorModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbBusyIndicatorModule, providers: [], imports: [[CommonModule, TranslateModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbBusyIndicatorModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, TranslateModule],
                    declarations: [NarikNgbBusyIndicator],
                    exports: [NarikNgbBusyIndicator],
                    providers: [],
                }]
        }] });

class NarikNgbButtonComponent extends NarikButton {
    constructor(renderer, injector) {
        super(injector);
        this.renderer = renderer;
    }
    onClick(event) {
        event.stopPropagation();
    }
    ngOnInit() {
        super.ngOnInit();
        this.buttonStyle = this.buttonStyle || this.defaultOptions.buttonStyle;
        this.busyFontIcon =
            this.busyFontIcon || this.defaultOptions.busyFontIcon;
    }
    ngAfterViewInit() { }
    buttonClick(e) {
        if (!this.disable && !this.isBusy) {
            this.nClick.emit({
                sender: this,
                event: e,
            });
        }
    }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbButtonComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbButtonComponent, deps: [{ token: i0.Renderer2 }, { token: i0.Injector }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbButtonComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbButtonComponent, selector: "narik-ngb-button , narik-button ", host: { listeners: { "click": "onClick($event)" } }, usesInheritance: true, ngImport: i0, template: "<button\n  ngbTooltip=\"{{(tooltip ?  (tooltip | translate) : '') + ( options.appendShortcutToTooltip && shortcut ? '(' + (shortcut | shortcut) +')' : '' )}}\"\n  container=\"body\"\n  placement=\"bottom\" (click)=\"buttonClick($event)\" [disabled]=\"disable || isBusy\" class=\"btn btn-{{buttonStyle}}\"\n  type=\"button\" [ngClass]='cssClass'>\n  <span *ngIf=\"isBusy\" class=\"mx-1 spinner-border spinner-border-sm\" role=\"status\" aria-hidden=\"true\"></span>\n  <i *ngIf=\"icon\" class=\"fa fa-{{icon}}\"></i>\n  {{ isBusy && busyLabel ? busyLabel : label}}\n</button>", directives: [{ type: i1$1.NgbTooltip, selector: "[ngbTooltip]", inputs: ["animation", "autoClose", "placement", "triggers", "container", "disableTooltip", "tooltipClass", "openDelay", "closeDelay", "ngbTooltip"], outputs: ["shown", "hidden"], exportAs: ["ngbTooltip"] }, { type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], pipes: { "translate": i4.TranslatePipe, "shortcut": i9.ShortcutPipe } });
__decorate([
    NarikInject(BUTTON_DEFAULT_OPTIONS, {
        buttonStyle: 'secondary',
        busyFontIcon: 'fa-spinner',
    }),
    __metadata("design:type", Object)
], NarikNgbButtonComponent.prototype, "defaultOptions", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbButtonComponent, decorators: [{
            type: Component,
            args: [{ selector: 'narik-ngb-button , narik-button ', template: "<button\n  ngbTooltip=\"{{(tooltip ?  (tooltip | translate) : '') + ( options.appendShortcutToTooltip && shortcut ? '(' + (shortcut | shortcut) +')' : '' )}}\"\n  container=\"body\"\n  placement=\"bottom\" (click)=\"buttonClick($event)\" [disabled]=\"disable || isBusy\" class=\"btn btn-{{buttonStyle}}\"\n  type=\"button\" [ngClass]='cssClass'>\n  <span *ngIf=\"isBusy\" class=\"mx-1 spinner-border spinner-border-sm\" role=\"status\" aria-hidden=\"true\"></span>\n  <i *ngIf=\"icon\" class=\"fa fa-{{icon}}\"></i>\n  {{ isBusy && busyLabel ? busyLabel : label}}\n</button>" }]
        }], ctorParameters: function () { return [{ type: i0.Renderer2 }, { type: i0.Injector }]; }, propDecorators: { defaultOptions: [], onClick: [{
                type: HostListener,
                args: ['click', ['$event']]
            }] } });

class NarikNgbButtonModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbButtonModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbButtonModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbButtonModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbButtonModule, declarations: [NarikNgbButtonComponent], imports: [CommonModule,
        NgbTooltipModule,
        TranslateModule,
        NarikCommonModule], exports: [NarikNgbButtonComponent] });
/** @nocollapse */ /** @nocollapse */ NarikNgbButtonModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbButtonModule, providers: [], imports: [[
            CommonModule,
            NgbTooltipModule,
            TranslateModule,
            NarikCommonModule,
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbButtonModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        NgbTooltipModule,
                        TranslateModule,
                        NarikCommonModule,
                    ],
                    declarations: [NarikNgbButtonComponent],
                    exports: [NarikNgbButtonComponent],
                    providers: [],
                }]
        }] });

class NarikNgbCheckBox extends NarikCheckBox {
    constructor(injector) {
        super(injector);
    }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbCheckBox.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCheckBox, deps: [{ token: i0.Injector }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbCheckBox.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbCheckBox, selector: "narik-ngb-checkbox , narik-checkbox", inputs: { tag: "tag", id: "id", name: "name", label: "label", disabled: "disabled", required: "required", readOnly: "readOnly", placeHolder: "placeHolder", options: "options" }, providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef((() => NarikNgbCheckBox)),
            multi: true,
        },
        {
            provide: NarikCheckBox,
            useExisting: forwardRef((() => NarikNgbCheckBox)),
        },
    ], usesInheritance: true, ngImport: i0, template: "<div class=\"form-check\">\n  <input [attr.disabled]=\"disabled || null\" class=\"form-check-input\" type=\"checkbox\"\n  [(ngModel)]=\"value\" id=\"{{id}}\">\n  <label class=\"form-check-label\" for=\"{{id}}\">\n    {{label}}\n  </label>\n</div>\n", directives: [{ type: i2.CheckboxControlValueAccessor, selector: "input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]" }, { type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCheckBox, decorators: [{
            type: Component,
            args: [{ selector: 'narik-ngb-checkbox , narik-checkbox', inputs: [...NARIK_CHECKBOX_INPUTS], providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef((() => NarikNgbCheckBox)),
                            multi: true,
                        },
                        {
                            provide: NarikCheckBox,
                            useExisting: forwardRef((() => NarikNgbCheckBox)),
                        },
                    ], template: "<div class=\"form-check\">\n  <input [attr.disabled]=\"disabled || null\" class=\"form-check-input\" type=\"checkbox\"\n  [(ngModel)]=\"value\" id=\"{{id}}\">\n  <label class=\"form-check-label\" for=\"{{id}}\">\n    {{label}}\n  </label>\n</div>\n" }]
        }], ctorParameters: function () { return [{ type: i0.Injector }]; } });

class NarikNgbCheckBoxModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbCheckBoxModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCheckBoxModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbCheckBoxModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCheckBoxModule, declarations: [NarikNgbCheckBox], imports: [CommonModule, FormsModule], exports: [NarikNgbCheckBox] });
/** @nocollapse */ /** @nocollapse */ NarikNgbCheckBoxModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCheckBoxModule, providers: [], imports: [[CommonModule, FormsModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCheckBoxModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, FormsModule],
                    declarations: [NarikNgbCheckBox],
                    exports: [NarikNgbCheckBox],
                    providers: [],
                }]
        }] });

class NarikNgbCheckBoxList extends NarikCheckBoxList {
    constructor(injector) {
        super(injector);
        this.itemsData = [];
        this._layoutDirection = 'vertical';
    }
    set layoutDirection(value) {
        this._layoutDirection = value;
    }
    get layoutDirection() {
        return this._layoutDirection;
    }
    useData(data) {
        this.itemsData = data;
    }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbCheckBoxList.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCheckBoxList, deps: [{ token: i0.Injector }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbCheckBoxList.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbCheckBoxList, selector: "narik-ngb-checkbox-list , narik-checkbox-list", inputs: { displayField: "displayField", valueField: "valueField", listenForDataChange: "listenForDataChange", dataSource: "dataSource", dataKey: "dataKey", dataUrl: "dataUrl", dataInfo: "dataInfo", dataProviderKey: "dataProviderKey", dataParameters: "dataParameters", moduleKey: "moduleKey", dataMethod: "dataMethod", dataUrlMethod: "dataUrlMethod", id: "id", name: "name", label: "label", disabled: "disabled", required: "required", readOnly: "readOnly", placeHolder: "placeHolder", options: "options", layoutDirection: "layoutDirection" }, providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef((() => NarikNgbCheckBoxList)),
            multi: true,
        },
    ], usesInheritance: true, ngImport: i0, template: "<div class=\"form-group\">\n  <label for=\"{{id}}\">{{label}}</label>\n  <div class=\"form-check-container p-1 pl-2\">\n    <div [ngClass]=\"{ 'vertical-content': layoutDirection == 'vertical' }\">\n      <narik-checkbox *ngFor=\"let item of itemsData\" (change)=\"addOrRemove(valueField ? item[valueField] : item)\"\n        [tag]=\"valueField ? item[valueField] : item\" label=\"{{ item[displayField] }}\">\n      </narik-checkbox>\n    </div>\n  </div>\n</div>\n", styles: [".form-check-container{border:1px solid #ced4da;border-radius:.25rem}\n"], components: [{ type: NarikNgbCheckBox, selector: "narik-ngb-checkbox , narik-checkbox", inputs: ["tag", "id", "name", "label", "disabled", "required", "readOnly", "placeHolder", "options"] }], directives: [{ type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCheckBoxList, decorators: [{
            type: Component,
            args: [{ selector: 'narik-ngb-checkbox-list , narik-checkbox-list', inputs: [...NARIK_DATA_DISPLAY_VALUE_INPUTS], providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef((() => NarikNgbCheckBoxList)),
                            multi: true,
                        },
                    ], template: "<div class=\"form-group\">\n  <label for=\"{{id}}\">{{label}}</label>\n  <div class=\"form-check-container p-1 pl-2\">\n    <div [ngClass]=\"{ 'vertical-content': layoutDirection == 'vertical' }\">\n      <narik-checkbox *ngFor=\"let item of itemsData\" (change)=\"addOrRemove(valueField ? item[valueField] : item)\"\n        [tag]=\"valueField ? item[valueField] : item\" label=\"{{ item[displayField] }}\">\n      </narik-checkbox>\n    </div>\n  </div>\n</div>\n", styles: [".form-check-container{border:1px solid #ced4da;border-radius:.25rem}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.Injector }]; }, propDecorators: { layoutDirection: [{
                type: Input
            }] } });

class NarikNgbCheckBoxListModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbCheckBoxListModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCheckBoxListModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbCheckBoxListModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCheckBoxListModule, declarations: [NarikNgbCheckBoxList], imports: [CommonModule, FormsModule, NarikNgbCheckBoxModule], exports: [NarikNgbCheckBoxList] });
/** @nocollapse */ /** @nocollapse */ NarikNgbCheckBoxListModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCheckBoxListModule, providers: [], imports: [[CommonModule, FormsModule, NarikNgbCheckBoxModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCheckBoxListModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, FormsModule, NarikNgbCheckBoxModule],
                    declarations: [NarikNgbCheckBoxList],
                    exports: [NarikNgbCheckBoxList],
                    providers: [],
                }]
        }] });

class NarikNgbDataTable extends NarikDataTable {
    constructor(injector, changeDetector, document) {
        super(injector);
        this.changeDetector = changeDetector;
        this.document = document;
    }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbDataTable.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDataTable, deps: [{ token: i0.Injector }, { token: i0.ChangeDetectorRef }, { token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbDataTable.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbDataTable, selector: "narik-ngb-data-table , narik-data-table", usesInheritance: true, ngImport: i0, template: "" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDataTable, decorators: [{
            type: Component,
            args: [{ selector: 'narik-ngb-data-table , narik-data-table', template: "" }]
        }], ctorParameters: function () { return [{ type: i0.Injector }, { type: i0.ChangeDetectorRef }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }]; } });

class NarikNgbDataTableModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbDataTableModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDataTableModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbDataTableModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDataTableModule, declarations: [NarikNgbDataTable], imports: [CommonModule, FormsModule, TranslateModule], exports: [NarikNgbDataTable] });
/** @nocollapse */ /** @nocollapse */ NarikNgbDataTableModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDataTableModule, providers: [], imports: [[CommonModule, FormsModule, TranslateModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDataTableModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, FormsModule, TranslateModule],
                    declarations: [NarikNgbDataTable],
                    exports: [NarikNgbDataTable],
                    providers: [],
                }]
        }] });

class NarikNgbDatePicker extends NarikDatePicker {
    constructor(injector) {
        super(injector);
    }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbDatePicker.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDatePicker, deps: [{ token: i0.Injector }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbDatePicker.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbDatePicker, selector: "narik-ngb-date-picker , narik-date-picker", inputs: { id: "id", name: "name", label: "label", disabled: "disabled", required: "required", readOnly: "readOnly", placeHolder: "placeHolder", options: "options" }, providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef((() => NarikNgbDatePicker)),
            multi: true,
        },
    ], usesInheritance: true, ngImport: i0, template: "<div class=\"form-group\">\n  <label for=\"{{id}}\">{{label}}</label>\n\n  <div class=\"input-group\">\n    <input [required]=\"required\" [attr.disabled]=\"disabled || null\" class=\"form-control\" id=\"{{id}}\" placeholder=\"{{placeHolder}}\" name=\"dp\"\n      [(ngModel)]=\"value\" ngbDatepicker #d=\"ngbDatepicker\">\n    <div class=\"input-group-append\">\n      <button class=\"btn btn-outline-secondary\" (click)=\"d.toggle()\" type=\"button\">\n        <i class=\"fa fa-calendar-alt\" aria-hidden=\"true\"></i>\n      </button>\n    </div>\n  </div>\n\n</div>\n", directives: [{ type: i1$1.NgbInputDatepicker, selector: "input[ngbDatepicker]", inputs: ["disabled", "autoClose", "datepickerClass", "dayTemplate", "dayTemplateData", "displayMonths", "firstDayOfWeek", "footerTemplate", "markDisabled", "minDate", "maxDate", "navigation", "outsideDays", "placement", "restoreFocus", "showWeekNumbers", "startDate", "container", "positionTarget", "weekdays"], outputs: ["dateSelect", "navigate", "closed"], exportAs: ["ngbDatepicker"] }, { type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { type: i2.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDatePicker, decorators: [{
            type: Component,
            args: [{ selector: 'narik-ngb-date-picker , narik-date-picker', inputs: [...NARIK_DATE_PICKER_INPUTS], providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef((() => NarikNgbDatePicker)),
                            multi: true,
                        },
                    ], template: "<div class=\"form-group\">\n  <label for=\"{{id}}\">{{label}}</label>\n\n  <div class=\"input-group\">\n    <input [required]=\"required\" [attr.disabled]=\"disabled || null\" class=\"form-control\" id=\"{{id}}\" placeholder=\"{{placeHolder}}\" name=\"dp\"\n      [(ngModel)]=\"value\" ngbDatepicker #d=\"ngbDatepicker\">\n    <div class=\"input-group-append\">\n      <button class=\"btn btn-outline-secondary\" (click)=\"d.toggle()\" type=\"button\">\n        <i class=\"fa fa-calendar-alt\" aria-hidden=\"true\"></i>\n      </button>\n    </div>\n  </div>\n\n</div>\n" }]
        }], ctorParameters: function () { return [{ type: i0.Injector }]; } });

class NarikNgbDatePickerModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbDatePickerModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDatePickerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbDatePickerModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDatePickerModule, declarations: [NarikNgbDatePicker], imports: [CommonModule, FormsModule, NgbDatepickerModule, TranslateModule], exports: [NarikNgbDatePicker] });
/** @nocollapse */ /** @nocollapse */ NarikNgbDatePickerModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDatePickerModule, providers: [{ provide: NgbDateAdapter, useClass: NgbDateNativeAdapter }], imports: [[CommonModule, FormsModule, NgbDatepickerModule, TranslateModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDatePickerModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, FormsModule, NgbDatepickerModule, TranslateModule],
                    declarations: [NarikNgbDatePicker],
                    exports: [NarikNgbDatePicker],
                    providers: [{ provide: NgbDateAdapter, useClass: NgbDateNativeAdapter }],
                }]
        }] });

class NarikNgbInput extends NarikInput {
    constructor(injector) {
        super(injector);
    }
    set icon(value) {
        this._icon = value;
    }
    get icon() {
        return this._icon;
    }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbInput.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbInput, deps: [{ token: i0.Injector }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbInput.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbInput, selector: "narik-ngb-input , narik-input", inputs: { maxlength: "maxlength", type: "type", mask: "mask", icon: "icon", displayStatus: "displayStatus", id: "id", name: "name", label: "label", disabled: "disabled", required: "required", readOnly: "readOnly", placeHolder: "placeHolder", options: "options" }, providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef((() => NarikNgbInput)),
            multi: true,
        },
    ], usesInheritance: true, ngImport: i0, template: "<div class=\"form-group \">\n  <label for=\"{{id}}\">{{label}}</label>\n  <div class=\"input-group mb-3\" *ngIf=\"icon\">\n    <div class=\"input-group-prepend\">\n      <span class=\"input-group-text\"><i class=\"fa fa-{{icon}}\"></i></span>\n    </div>\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\n  </div>\n  <ng-container *ngIf=\"!icon\">\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\n  </ng-container>\n\n</div>\n<ng-template #inputElement>\n  <input [(ngModel)]=\"value\" [attr.disabled]=\"disabled || null\" type=\"{{type}}\" name=\"{{name}}\" [required]=\"required\"\n    class=\"form-control\" id=\"{{id}}\" placeholder=\"{{placeHolder}}\">\n</ng-template>", directives: [{ type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }, { type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { type: i2.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbInput, decorators: [{
            type: Component,
            args: [{ selector: 'narik-ngb-input , narik-input', inputs: [...NARIK_INPUT_INPUTS], providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef((() => NarikNgbInput)),
                            multi: true,
                        },
                    ], template: "<div class=\"form-group \">\n  <label for=\"{{id}}\">{{label}}</label>\n  <div class=\"input-group mb-3\" *ngIf=\"icon\">\n    <div class=\"input-group-prepend\">\n      <span class=\"input-group-text\"><i class=\"fa fa-{{icon}}\"></i></span>\n    </div>\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\n  </div>\n  <ng-container *ngIf=\"!icon\">\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\n  </ng-container>\n\n</div>\n<ng-template #inputElement>\n  <input [(ngModel)]=\"value\" [attr.disabled]=\"disabled || null\" type=\"{{type}}\" name=\"{{name}}\" [required]=\"required\"\n    class=\"form-control\" id=\"{{id}}\" placeholder=\"{{placeHolder}}\">\n</ng-template>" }]
        }], ctorParameters: function () { return [{ type: i0.Injector }]; }, propDecorators: { icon: [{
                type: Input
            }] } });

class NarikNgbInputModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbInputModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbInputModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbInputModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbInputModule, declarations: [NarikNgbInput], imports: [CommonModule, FormsModule], exports: [NarikNgbInput] });
/** @nocollapse */ /** @nocollapse */ NarikNgbInputModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbInputModule, providers: [], imports: [[CommonModule, FormsModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbInputModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, FormsModule],
                    declarations: [NarikNgbInput],
                    exports: [NarikNgbInput],
                    providers: [],
                }]
        }] });

class NarikNgbRadioGroup extends NarikRadioGroup {
    constructor(injector) {
        super(injector);
        this.itemsData = [];
        this._layoutDirection = 'vertical';
    }
    set layoutDirection(value) {
        this._layoutDirection = value;
    }
    get layoutDirection() {
        return this._layoutDirection;
    }
    useData(data) {
        this.itemsData = data;
    }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbRadioGroup.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbRadioGroup, deps: [{ token: i0.Injector }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbRadioGroup.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbRadioGroup, selector: "narik-ngb-radio-group , narik-radio-group", inputs: { displayField: "displayField", valueField: "valueField", listenForDataChange: "listenForDataChange", dataSource: "dataSource", dataKey: "dataKey", dataUrl: "dataUrl", dataInfo: "dataInfo", dataProviderKey: "dataProviderKey", dataParameters: "dataParameters", moduleKey: "moduleKey", dataMethod: "dataMethod", dataUrlMethod: "dataUrlMethod", id: "id", name: "name", label: "label", disabled: "disabled", required: "required", readOnly: "readOnly", placeHolder: "placeHolder", options: "options", layoutDirection: "layoutDirection" }, providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef((() => NarikNgbRadioGroup)),
            multi: true,
        },
    ], usesInheritance: true, ngImport: i0, template: "<div class=\"form-group\">\n  <label for=\"{{id}}\">{{label}}</label>\n  <div class=\"form-check-container p-1 pl-2\">\n    <div class=\"form-check \" [ngClass]=\"{'form-check-inline': layoutDirection==='horizontal'}\"\n      *ngFor=\"let item of itemsData;let i=index\">\n      <input [required]=\"required\" [attr.disabled]=\"disabled || null\" class=\"form-check-input\" type=\"radio\" name=\"{{name}}\" id=\"{{id+i}}\"\n        value=\"{{item[valueField]}}\" checked>\n      <label class=\"form-check-label\" for=\"{{id+i}}\">\n        {{item[displayField]}}\n      </label>\n    </div>\n  </div>\n</div>\n", styles: [".form-check-container{border:1px solid #ced4da;border-radius:.25rem}\n"], directives: [{ type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbRadioGroup, decorators: [{
            type: Component,
            args: [{ selector: 'narik-ngb-radio-group , narik-radio-group', inputs: [...NARIK_DATA_DISPLAY_VALUE_INPUTS], providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef((() => NarikNgbRadioGroup)),
                            multi: true,
                        },
                    ], template: "<div class=\"form-group\">\n  <label for=\"{{id}}\">{{label}}</label>\n  <div class=\"form-check-container p-1 pl-2\">\n    <div class=\"form-check \" [ngClass]=\"{'form-check-inline': layoutDirection==='horizontal'}\"\n      *ngFor=\"let item of itemsData;let i=index\">\n      <input [required]=\"required\" [attr.disabled]=\"disabled || null\" class=\"form-check-input\" type=\"radio\" name=\"{{name}}\" id=\"{{id+i}}\"\n        value=\"{{item[valueField]}}\" checked>\n      <label class=\"form-check-label\" for=\"{{id+i}}\">\n        {{item[displayField]}}\n      </label>\n    </div>\n  </div>\n</div>\n", styles: [".form-check-container{border:1px solid #ced4da;border-radius:.25rem}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.Injector }]; }, propDecorators: { layoutDirection: [{
                type: Input
            }] } });

class NarikNgbRadioGroupModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbRadioGroupModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbRadioGroupModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbRadioGroupModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbRadioGroupModule, declarations: [NarikNgbRadioGroup], imports: [CommonModule, FormsModule], exports: [NarikNgbRadioGroup] });
/** @nocollapse */ /** @nocollapse */ NarikNgbRadioGroupModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbRadioGroupModule, providers: [], imports: [[CommonModule, FormsModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbRadioGroupModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, FormsModule],
                    declarations: [NarikNgbRadioGroup],
                    exports: [NarikNgbRadioGroup],
                    providers: [],
                }]
        }] });

class NarikNgbSelect extends NarikSelect {
    constructor(injector) {
        super(injector);
        this.optionData = [];
    }
    useData(data) {
        this.optionData = data;
    }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbSelect.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbSelect, deps: [{ token: i0.Injector }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbSelect.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbSelect, selector: "narik-ngb-select , narik-select", inputs: { displayField: "displayField", valueField: "valueField", listenForDataChange: "listenForDataChange", dataSource: "dataSource", dataKey: "dataKey", dataUrl: "dataUrl", dataInfo: "dataInfo", dataProviderKey: "dataProviderKey", dataParameters: "dataParameters", moduleKey: "moduleKey", dataMethod: "dataMethod", dataUrlMethod: "dataUrlMethod", id: "id", name: "name", label: "label", disabled: "disabled", required: "required", readOnly: "readOnly", placeHolder: "placeHolder", options: "options", multiple: "multiple", icon: "icon" }, outputs: { dataChange: "dataChange", selectedItemChange: "selectedItemChange" }, providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef((() => NarikNgbSelect)),
            multi: true,
        },
    ], usesInheritance: true, ngImport: i0, template: "<div class=\"form-group\">\n  <label for=\"{{id}}\">{{label}}</label>\n  <div class=\"input-group mb-3\" *ngIf=\"icon\">\n    <div class=\"input-group-prepend\">\n      <span class=\"input-group-text\"><i class=\"fa fa-{{icon}}\"></i></span>\n    </div>\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\n  </div>\n  <ng-container *ngIf=\"!icon\">\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\n  </ng-container>\n\n</div>\n<ng-template #inputElement>\n\n  <select [required]=\"required\" class=\"custom-select\" [(ngModel)]=\"value\" [attr.disabled]=\"disabled || null\"\n    id=\"{{id}}\">\n    <option *ngFor=\"let item of optionData\" [value]=\"item[valueField]\">{{item[displayField]}}</option>\n  </select>\n\n\n\n</ng-template>", styles: [".select-clear{position:absolute;left:-2px;top:-30px}.search-input{padding:16px;box-sizing:border-box}.search-continer{border-bottom:1px solid rgba(0,0,0,.12);top:0;width:100%;position:sticky;background-color:#fff;z-index:10000}\n"], directives: [{ type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }, { type: i2.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { type: i2.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i2.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { type: i2.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbSelect, decorators: [{
            type: Component,
            args: [{ selector: 'narik-ngb-select , narik-select', inputs: [...NARIK_DATA_DISPLAY_VALUE_INPUTS, ...NARIK_SELECT_INPUTS], outputs: [...NARIK_DATA_DISPLAY_VALUE_OUTPUTS], providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef((() => NarikNgbSelect)),
                            multi: true,
                        },
                    ], template: "<div class=\"form-group\">\n  <label for=\"{{id}}\">{{label}}</label>\n  <div class=\"input-group mb-3\" *ngIf=\"icon\">\n    <div class=\"input-group-prepend\">\n      <span class=\"input-group-text\"><i class=\"fa fa-{{icon}}\"></i></span>\n    </div>\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\n  </div>\n  <ng-container *ngIf=\"!icon\">\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\n  </ng-container>\n\n</div>\n<ng-template #inputElement>\n\n  <select [required]=\"required\" class=\"custom-select\" [(ngModel)]=\"value\" [attr.disabled]=\"disabled || null\"\n    id=\"{{id}}\">\n    <option *ngFor=\"let item of optionData\" [value]=\"item[valueField]\">{{item[displayField]}}</option>\n  </select>\n\n\n\n</ng-template>", styles: [".select-clear{position:absolute;left:-2px;top:-30px}.search-input{padding:16px;box-sizing:border-box}.search-continer{border-bottom:1px solid rgba(0,0,0,.12);top:0;width:100%;position:sticky;background-color:#fff;z-index:10000}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.Injector }]; }, propDecorators: { icon: [{
                type: Input
            }] } });

class NarikNgbSelectModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbSelectModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbSelectModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbSelectModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbSelectModule, declarations: [NarikNgbSelect], imports: [CommonModule, FormsModule], exports: [NarikNgbSelect] });
/** @nocollapse */ /** @nocollapse */ NarikNgbSelectModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbSelectModule, providers: [], imports: [[CommonModule, FormsModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbSelectModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, FormsModule],
                    declarations: [NarikNgbSelect],
                    exports: [NarikNgbSelect],
                    providers: [],
                }]
        }] });

class NarikNgbDynamicForm extends NarikDynamicForm {
    constructor(injector, viewContainerRef) {
        super(injector, viewContainerRef);
        this.columnWidth = 100;
        this.fieldsArray = new Map();
    }
    ngOnInit() {
        super.ngOnInit();
        if (this.columnsCount === 1) {
            this.layoutGap = 0;
        }
        if (this.groupFields) {
            const data = groupBy(this.fields, 'options.groupIndex');
            data.forEach((x) => this.fieldsArray.set(x.key && x.key !== 'undefined' ? +x.key : 0, x.value));
            this.groupCount =
                Math.max(...this.fieldsArray.entriesArray().map((x) => x.key)) +
                    1;
        }
        this.columnWidth = 100 / this.columnsCount;
    }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbDynamicForm.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDynamicForm, deps: [{ token: i0.Injector }, { token: i0.ViewContainerRef }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbDynamicForm.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbDynamicForm, selector: "narik-dynamic-form , narik-ngb-dynamic-form", providers: [
        {
            provide: NarikDynamicForm,
            useExisting: forwardRef((() => NarikNgbDynamicForm)),
        },
    ], usesInheritance: true, ngImport: i0, template: "<div\n  [tab-guard]=\"activeTabGuard\"\n  [auto-focus]=\"activeAutoFocus\"\n  [autoFocusContainerName]=\"defaultFocusField\"\n  fxLayout=\"{{ columnsCount === 1 ? 'column' : 'row wrap' }} \"\n  fxLayout.xs=\"column\"\n  fxLayoutGap.xs=\"0\"\n  fxLayoutGap=\"{{ layoutGap }}px\"\n  fxLayoutAlign=\"flex-start\"\n>\n  <ng-container *ngIf=\"!groupFields\">\n    <div\n      fxFlex.gt-xs=\"0 1 calc({{ columnWidth }}% - {{ layoutGap }}px)\"\n      fxFlex=\"100%\"\n      *ngFor=\"let item of fields; let i = index\"\n    >\n      <ng-container\n        *ngTemplateOutlet=\"\n          fieldContainer;\n          context: {\n            $implicit: item,\n            invisibleItems: invisibleItems,\n            disableItems: disableItems,\n            model: model,\n            form: form\n          }\n        \"\n      ></ng-container>\n    </div>\n  </ng-container>\n  <ng-container *ngIf=\"groupFields\">\n    <div\n      fxFlex.gt-xs=\"0 1 calc({{ columnWidth }}% - {{ layoutGap }}px)\"\n      fxFlex=\"100%\"\n      *ngFor=\"let item of [].constructor(groupCount); let i = index\"\n    >\n      <div fxLayout=\"column\" class=\"narik-form-group\">\n        <div *ngFor=\"let item of fieldsArray.get(i); let j = index\">\n          <ng-container\n            *ngTemplateOutlet=\"\n              fieldContainer;\n              context: {\n                $implicit: item,\n                invisibleItems: invisibleItems,\n                disableItems: disableItems,\n                model: model,\n                form: form\n              }\n            \"\n          ></ng-container>\n        </div>\n      </div>\n    </div>\n  </ng-container>\n</div>\n\n<ng-template\n  #fieldContainer\n  let-item\n  let-invisibleItems=\"invisibleItems\"\n  let-model=\"model\"\n  let-form=\"form\"\n  let-disableItems=\"disableItems\"\n>\n  <ng-container\n    [formGroup]=\"form\"\n    *ngIf=\"!item.hideExpr || !invisibleItems[item.name]\"\n  >\n    <ng-container *ngIf=\"!customFormComponentKeysObject[item.type || 'text']\">\n      <ng-container\n        *ngIf=\"\n          !item.type ||\n          item.type == 'text' ||\n          item.type == 'number' ||\n          item.type == 'time' ||\n          item.type == 'textArea' ||\n          item.type == 'password'\n        \"\n      >\n        <narik-input\n          [name]=\"item.name\"\n          [required]=\"item.required\"\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\n          [type]=\"item.type || 'text'\"\n          label=\"{{ item.label | translate }}\"\n          [formControlName]=\"item.model\"\n          [options]=\"item.options\"\n        >\n        </narik-input>\n      </ng-container>\n      <ng-container *ngIf=\"item.type == 'boolean'\">\n        <narik-checkbox\n          [name]=\"item.name\"\n          [options]=\"item.options\"\n          [formControlName]=\"item.model\"\n          label=\"{{ item.label | translate }}\"\n        >\n        </narik-checkbox>\n      </ng-container>\n      <ng-container *ngIf=\"item.type == 'date'\">\n        <narik-date-picker\n          [options]=\"item.options\"\n          [name]=\"item.name\"\n          [required]=\"item.required\"\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\n          [formControlName]=\"item.model\"\n          label=\"{{ item.label | translate }}\"\n        ></narik-date-picker>\n      </ng-container>\n      <ng-container *ngIf=\"item.type == 'select'\">\n        <narik-select\n          [options]=\"item.options\"\n          [name]=\"item.name\"\n          [required]=\"item.required\"\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\n          [dataInfo]=\"item.dataInfo\"\n          label=\"{{ item.label | translate }}\"\n          [formControlName]=\"item.model\"\n        ></narik-select>\n      </ng-container>\n      <ng-container *ngIf=\"item.type == 'autoComplete'\">\n        <narik-autocomplete\n          [options]=\"item.options\"\n          [name]=\"item.name\"\n          [required]=\"item.required\"\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\n          [minSearchLength]=\"item.options.minSearchLength || 0\"\n          [isLazyLoadData]=\"item.options.isLazyLoadData\"\n          [dataInfo]=\"item.dataInfo\"\n          label=\"{{ item.label | translate }}\"\n          [formControlName]=\"item.model\"\n        ></narik-autocomplete>\n      </ng-container>\n      <ng-container *ngIf=\"item.type == 'radio'\">\n        <narik-radio-group\n          [options]=\"item.options\"\n          [name]=\"item.name\"\n          [required]=\"item.required\"\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\n          [dataInfo]=\"item.dataInfo\"\n          label=\"{{ item.label | translate }}\"\n          [formControlName]=\"item.model\"\n        ></narik-radio-group>\n      </ng-container>\n      <ng-container *ngIf=\"item.type == 'checkList'\">\n        <narik-checkbox-list\n          [options]=\"item.options\"\n          [name]=\"item.name\"\n          [required]=\"item.required\"\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\n          [dataInfo]=\"item.dataInfo\"\n          label=\"{{ item.label | translate }}\"\n          [formControlName]=\"item.model\"\n        ></narik-checkbox-list>\n      </ng-container>\n      <ng-container *ngIf=\"item.type == 'table-select'\"> </ng-container>\n    </ng-container>\n    <ng-container *ngIf=\"customFormComponentKeysObject[item.type || 'text']\">\n      <ng-container\n        *narikComponentLoader=\"\n          customFormComponentKeysObject[item.type || 'text'];\n          bindings: {\n            field: item,\n            model: model\n          };\n          bindingSource: this;\n          parameters: {\n            form: form\n          }\n        \"\n      ></ng-container>\n    </ng-container>\n  </ng-container>\n</ng-template>\n", components: [{ type: NarikNgbInput, selector: "narik-ngb-input , narik-input", inputs: ["maxlength", "type", "mask", "icon", "displayStatus", "id", "name", "label", "disabled", "required", "readOnly", "placeHolder", "options"] }, { type: NarikNgbCheckBox, selector: "narik-ngb-checkbox , narik-checkbox", inputs: ["tag", "id", "name", "label", "disabled", "required", "readOnly", "placeHolder", "options"] }, { type: NarikNgbDatePicker, selector: "narik-ngb-date-picker , narik-date-picker", inputs: ["id", "name", "label", "disabled", "required", "readOnly", "placeHolder", "options"] }, { type: NarikNgbSelect, selector: "narik-ngb-select , narik-select", inputs: ["displayField", "valueField", "listenForDataChange", "dataSource", "dataKey", "dataUrl", "dataInfo", "dataProviderKey", "dataParameters", "moduleKey", "dataMethod", "dataUrlMethod", "id", "name", "label", "disabled", "required", "readOnly", "placeHolder", "options", "multiple", "icon"], outputs: ["dataChange", "selectedItemChange"] }, { type: NarikNgbAutoComplete, selector: "narik-ngb-autocomplete  , narik-autocomplete ", inputs: ["displayField", "valueField", "listenForDataChange", "dataSource", "dataKey", "dataUrl", "dataInfo", "dataProviderKey", "dataParameters", "moduleKey", "dataMethod", "dataUrlMethod", "id", "name", "label", "disabled", "required", "readOnly", "placeHolder", "options", "icon"], outputs: ["dataChange", "selectedItemChange"] }, { type: NarikNgbRadioGroup, selector: "narik-ngb-radio-group , narik-radio-group", inputs: ["displayField", "valueField", "listenForDataChange", "dataSource", "dataKey", "dataUrl", "dataInfo", "dataProviderKey", "dataParameters", "moduleKey", "dataMethod", "dataUrlMethod", "id", "name", "label", "disabled", "required", "readOnly", "placeHolder", "options", "layoutDirection"] }, { type: NarikNgbCheckBoxList, selector: "narik-ngb-checkbox-list , narik-checkbox-list", inputs: ["displayField", "valueField", "listenForDataChange", "dataSource", "dataKey", "dataUrl", "dataInfo", "dataProviderKey", "dataParameters", "moduleKey", "dataMethod", "dataUrlMethod", "id", "name", "label", "disabled", "required", "readOnly", "placeHolder", "options", "layoutDirection"] }], directives: [{ type: i8.DefaultLayoutDirective, selector: "  [fxLayout], [fxLayout.xs], [fxLayout.sm], [fxLayout.md],  [fxLayout.lg], [fxLayout.xl], [fxLayout.lt-sm], [fxLayout.lt-md],  [fxLayout.lt-lg], [fxLayout.lt-xl], [fxLayout.gt-xs], [fxLayout.gt-sm],  [fxLayout.gt-md], [fxLayout.gt-lg]", inputs: ["fxLayout", "fxLayout.xs", "fxLayout.sm", "fxLayout.md", "fxLayout.lg", "fxLayout.xl", "fxLayout.lt-sm", "fxLayout.lt-md", "fxLayout.lt-lg", "fxLayout.lt-xl", "fxLayout.gt-xs", "fxLayout.gt-sm", "fxLayout.gt-md", "fxLayout.gt-lg"] }, { type: i8.DefaultLayoutGapDirective, selector: "  [fxLayoutGap], [fxLayoutGap.xs], [fxLayoutGap.sm], [fxLayoutGap.md],  [fxLayoutGap.lg], [fxLayoutGap.xl], [fxLayoutGap.lt-sm], [fxLayoutGap.lt-md],  [fxLayoutGap.lt-lg], [fxLayoutGap.lt-xl], [fxLayoutGap.gt-xs], [fxLayoutGap.gt-sm],  [fxLayoutGap.gt-md], [fxLayoutGap.gt-lg]", inputs: ["fxLayoutGap", "fxLayoutGap.xs", "fxLayoutGap.sm", "fxLayoutGap.md", "fxLayoutGap.lg", "fxLayoutGap.xl", "fxLayoutGap.lt-sm", "fxLayoutGap.lt-md", "fxLayoutGap.lt-lg", "fxLayoutGap.lt-xl", "fxLayoutGap.gt-xs", "fxLayoutGap.gt-sm", "fxLayoutGap.gt-md", "fxLayoutGap.gt-lg"] }, { type: i8.DefaultLayoutAlignDirective, selector: "  [fxLayoutAlign], [fxLayoutAlign.xs], [fxLayoutAlign.sm], [fxLayoutAlign.md],  [fxLayoutAlign.lg], [fxLayoutAlign.xl], [fxLayoutAlign.lt-sm], [fxLayoutAlign.lt-md],  [fxLayoutAlign.lt-lg], [fxLayoutAlign.lt-xl], [fxLayoutAlign.gt-xs], [fxLayoutAlign.gt-sm],  [fxLayoutAlign.gt-md], [fxLayoutAlign.gt-lg]", inputs: ["fxLayoutAlign", "fxLayoutAlign.xs", "fxLayoutAlign.sm", "fxLayoutAlign.md", "fxLayoutAlign.lg", "fxLayoutAlign.xl", "fxLayoutAlign.lt-sm", "fxLayoutAlign.lt-md", "fxLayoutAlign.lt-lg", "fxLayoutAlign.lt-xl", "fxLayoutAlign.gt-xs", "fxLayoutAlign.gt-sm", "fxLayoutAlign.gt-md", "fxLayoutAlign.gt-lg"] }, { type: i9.TabGuardDirective, selector: "[tab-guard]", inputs: ["tab-guard"] }, { type: i9.AutoFocusDirective, selector: "[auto-focus]", inputs: ["auto-focus", "autoFocusContainerName", "timeout"] }, { type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i8.DefaultFlexDirective, selector: "  [fxFlex], [fxFlex.xs], [fxFlex.sm], [fxFlex.md],  [fxFlex.lg], [fxFlex.xl], [fxFlex.lt-sm], [fxFlex.lt-md],  [fxFlex.lt-lg], [fxFlex.lt-xl], [fxFlex.gt-xs], [fxFlex.gt-sm],  [fxFlex.gt-md], [fxFlex.gt-lg]", inputs: ["fxFlex", "fxFlex.xs", "fxFlex.sm", "fxFlex.md", "fxFlex.lg", "fxFlex.xl", "fxFlex.lt-sm", "fxFlex.lt-md", "fxFlex.lt-lg", "fxFlex.lt-xl", "fxFlex.gt-xs", "fxFlex.gt-sm", "fxFlex.gt-md", "fxFlex.gt-lg"] }, { type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }, { type: i2.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { type: i2.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { type: i2.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i2.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { type: i9.NarikComponentLoaderDirective, selector: "[narikComponentLoader]", inputs: ["narikComponentLoader", "narikComponentLoaderParameters", "narikComponentLoaderBindings", "narikComponentLoaderBindingSource", "narikComponentLoaderProviders", "narikComponentLoaderEvents"] }], pipes: { "translate": i4.TranslatePipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDynamicForm, decorators: [{
            type: Component,
            args: [{ selector: 'narik-dynamic-form , narik-ngb-dynamic-form', providers: [
                        {
                            provide: NarikDynamicForm,
                            useExisting: forwardRef((() => NarikNgbDynamicForm)),
                        },
                    ], template: "<div\n  [tab-guard]=\"activeTabGuard\"\n  [auto-focus]=\"activeAutoFocus\"\n  [autoFocusContainerName]=\"defaultFocusField\"\n  fxLayout=\"{{ columnsCount === 1 ? 'column' : 'row wrap' }} \"\n  fxLayout.xs=\"column\"\n  fxLayoutGap.xs=\"0\"\n  fxLayoutGap=\"{{ layoutGap }}px\"\n  fxLayoutAlign=\"flex-start\"\n>\n  <ng-container *ngIf=\"!groupFields\">\n    <div\n      fxFlex.gt-xs=\"0 1 calc({{ columnWidth }}% - {{ layoutGap }}px)\"\n      fxFlex=\"100%\"\n      *ngFor=\"let item of fields; let i = index\"\n    >\n      <ng-container\n        *ngTemplateOutlet=\"\n          fieldContainer;\n          context: {\n            $implicit: item,\n            invisibleItems: invisibleItems,\n            disableItems: disableItems,\n            model: model,\n            form: form\n          }\n        \"\n      ></ng-container>\n    </div>\n  </ng-container>\n  <ng-container *ngIf=\"groupFields\">\n    <div\n      fxFlex.gt-xs=\"0 1 calc({{ columnWidth }}% - {{ layoutGap }}px)\"\n      fxFlex=\"100%\"\n      *ngFor=\"let item of [].constructor(groupCount); let i = index\"\n    >\n      <div fxLayout=\"column\" class=\"narik-form-group\">\n        <div *ngFor=\"let item of fieldsArray.get(i); let j = index\">\n          <ng-container\n            *ngTemplateOutlet=\"\n              fieldContainer;\n              context: {\n                $implicit: item,\n                invisibleItems: invisibleItems,\n                disableItems: disableItems,\n                model: model,\n                form: form\n              }\n            \"\n          ></ng-container>\n        </div>\n      </div>\n    </div>\n  </ng-container>\n</div>\n\n<ng-template\n  #fieldContainer\n  let-item\n  let-invisibleItems=\"invisibleItems\"\n  let-model=\"model\"\n  let-form=\"form\"\n  let-disableItems=\"disableItems\"\n>\n  <ng-container\n    [formGroup]=\"form\"\n    *ngIf=\"!item.hideExpr || !invisibleItems[item.name]\"\n  >\n    <ng-container *ngIf=\"!customFormComponentKeysObject[item.type || 'text']\">\n      <ng-container\n        *ngIf=\"\n          !item.type ||\n          item.type == 'text' ||\n          item.type == 'number' ||\n          item.type == 'time' ||\n          item.type == 'textArea' ||\n          item.type == 'password'\n        \"\n      >\n        <narik-input\n          [name]=\"item.name\"\n          [required]=\"item.required\"\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\n          [type]=\"item.type || 'text'\"\n          label=\"{{ item.label | translate }}\"\n          [formControlName]=\"item.model\"\n          [options]=\"item.options\"\n        >\n        </narik-input>\n      </ng-container>\n      <ng-container *ngIf=\"item.type == 'boolean'\">\n        <narik-checkbox\n          [name]=\"item.name\"\n          [options]=\"item.options\"\n          [formControlName]=\"item.model\"\n          label=\"{{ item.label | translate }}\"\n        >\n        </narik-checkbox>\n      </ng-container>\n      <ng-container *ngIf=\"item.type == 'date'\">\n        <narik-date-picker\n          [options]=\"item.options\"\n          [name]=\"item.name\"\n          [required]=\"item.required\"\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\n          [formControlName]=\"item.model\"\n          label=\"{{ item.label | translate }}\"\n        ></narik-date-picker>\n      </ng-container>\n      <ng-container *ngIf=\"item.type == 'select'\">\n        <narik-select\n          [options]=\"item.options\"\n          [name]=\"item.name\"\n          [required]=\"item.required\"\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\n          [dataInfo]=\"item.dataInfo\"\n          label=\"{{ item.label | translate }}\"\n          [formControlName]=\"item.model\"\n        ></narik-select>\n      </ng-container>\n      <ng-container *ngIf=\"item.type == 'autoComplete'\">\n        <narik-autocomplete\n          [options]=\"item.options\"\n          [name]=\"item.name\"\n          [required]=\"item.required\"\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\n          [minSearchLength]=\"item.options.minSearchLength || 0\"\n          [isLazyLoadData]=\"item.options.isLazyLoadData\"\n          [dataInfo]=\"item.dataInfo\"\n          label=\"{{ item.label | translate }}\"\n          [formControlName]=\"item.model\"\n        ></narik-autocomplete>\n      </ng-container>\n      <ng-container *ngIf=\"item.type == 'radio'\">\n        <narik-radio-group\n          [options]=\"item.options\"\n          [name]=\"item.name\"\n          [required]=\"item.required\"\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\n          [dataInfo]=\"item.dataInfo\"\n          label=\"{{ item.label | translate }}\"\n          [formControlName]=\"item.model\"\n        ></narik-radio-group>\n      </ng-container>\n      <ng-container *ngIf=\"item.type == 'checkList'\">\n        <narik-checkbox-list\n          [options]=\"item.options\"\n          [name]=\"item.name\"\n          [required]=\"item.required\"\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\n          [dataInfo]=\"item.dataInfo\"\n          label=\"{{ item.label | translate }}\"\n          [formControlName]=\"item.model\"\n        ></narik-checkbox-list>\n      </ng-container>\n      <ng-container *ngIf=\"item.type == 'table-select'\"> </ng-container>\n    </ng-container>\n    <ng-container *ngIf=\"customFormComponentKeysObject[item.type || 'text']\">\n      <ng-container\n        *narikComponentLoader=\"\n          customFormComponentKeysObject[item.type || 'text'];\n          bindings: {\n            field: item,\n            model: model\n          };\n          bindingSource: this;\n          parameters: {\n            form: form\n          }\n        \"\n      ></ng-container>\n    </ng-container>\n  </ng-container>\n</ng-template>\n" }]
        }], ctorParameters: function () { return [{ type: i0.Injector }, { type: i0.ViewContainerRef }]; } });

class NarikNgbDynamicFormModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbDynamicFormModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDynamicFormModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbDynamicFormModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDynamicFormModule, declarations: [NarikNgbDynamicForm], imports: [CommonModule,
        ReactiveFormsModule,
        TranslateModule,
        NarikNgbInputModule,
        NarikNgbSelectModule,
        NarikNgbCheckBoxModule,
        NarikNgbRadioGroupModule,
        NarikNgbAutoCompleteModule,
        NarikNgbDatePickerModule,
        NarikNgbCheckBoxListModule,
        NarikCommonModule,
        FlexLayoutModule], exports: [NarikNgbDynamicForm] });
/** @nocollapse */ /** @nocollapse */ NarikNgbDynamicFormModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDynamicFormModule, providers: [], imports: [[
            CommonModule,
            ReactiveFormsModule,
            TranslateModule,
            NarikNgbInputModule,
            NarikNgbSelectModule,
            NarikNgbCheckBoxModule,
            NarikNgbRadioGroupModule,
            NarikNgbAutoCompleteModule,
            NarikNgbDatePickerModule,
            NarikNgbCheckBoxListModule,
            NarikCommonModule,
            FlexLayoutModule,
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDynamicFormModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        ReactiveFormsModule,
                        TranslateModule,
                        NarikNgbInputModule,
                        NarikNgbSelectModule,
                        NarikNgbCheckBoxModule,
                        NarikNgbRadioGroupModule,
                        NarikNgbAutoCompleteModule,
                        NarikNgbDatePickerModule,
                        NarikNgbCheckBoxListModule,
                        NarikCommonModule,
                        FlexLayoutModule,
                    ],
                    declarations: [NarikNgbDynamicForm],
                    exports: [NarikNgbDynamicForm],
                    providers: [],
                }]
        }] });

class NarikNgbDialogContainer extends NarikDialogContainer {
    ngOnInit() { }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbDialogContainer.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDialogContainer, deps: null, target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbDialogContainer.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbDialogContainer, selector: "ng-component", usesInheritance: true, ngImport: i0, template: "<div\n  [@openClose]=\"isOpen ? 'open' : 'closed'\"\n  [class]=\"options.dialogCssClass\"\n  (@openClose.done)=\"_onAnimationDone($event)\"\n  class=\"modal-content\"\n  cdkDrag\n  [tab-guard]=\"true\"\n>\n  <div class=\"modal-header\">\n    <h5 cdkDragHandle class=\"modal-title\">{{ title | translate }}</h5>\n  </div>\n\n  <div class=\"modal-body\">\n    <ng-template narik-loader-host></ng-template>\n  </div>\n\n  <div\n    class=\"modal-footer\"\n    [auto-focus]=\"true\"\n    [autoFocusContainerName]=\"options.defaultAction\"\n    *ngIf=\"actions && actions.length !== 0\"\n    align=\"end\"\n  >\n    <ng-container *ngFor=\"let item of actions\">\n      <ng-container>\n        <narik-button\n          cssClass=\"btn-sm\"\n          [attr.narik-form-item-key]=\"item.dialogResult\"\n          class=\"mr-2\"\n          (nClick)=\"actionClick(item)\"\n          [color]=\"item.color\"\n          [icon]=\"item.icon\"\n          label=\"{{ 'dialog-buttons.' + item.label | translate }}\"\n        ></narik-button>\n      </ng-container>\n    </ng-container>\n  </div>\n</div>\n", styles: [".dialog-container{background-color:#fff;border-radius:5px;box-shadow:20px 20px 15px -7px #0003,0 24px 38px 3px #00000024,0 9px 46px 8px #0000001f}\n"], components: [{ type: NarikNgbButtonComponent, selector: "narik-ngb-button , narik-button " }], directives: [{ type: i9.TabGuardDirective, selector: "[tab-guard]", inputs: ["tab-guard"] }, { type: i9.ComponentLoaderHostDirective, selector: "[narik-loader-host]" }, { type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i9.AutoFocusDirective, selector: "[auto-focus]", inputs: ["auto-focus", "autoFocusContainerName", "timeout"] }, { type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }], pipes: { "translate": i4.TranslatePipe }, animations: [trigger('openClose', DialogAnimationBody)] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDialogContainer, decorators: [{
            type: Component,
            args: [{ animations: [trigger('openClose', DialogAnimationBody)], template: "<div\n  [@openClose]=\"isOpen ? 'open' : 'closed'\"\n  [class]=\"options.dialogCssClass\"\n  (@openClose.done)=\"_onAnimationDone($event)\"\n  class=\"modal-content\"\n  cdkDrag\n  [tab-guard]=\"true\"\n>\n  <div class=\"modal-header\">\n    <h5 cdkDragHandle class=\"modal-title\">{{ title | translate }}</h5>\n  </div>\n\n  <div class=\"modal-body\">\n    <ng-template narik-loader-host></ng-template>\n  </div>\n\n  <div\n    class=\"modal-footer\"\n    [auto-focus]=\"true\"\n    [autoFocusContainerName]=\"options.defaultAction\"\n    *ngIf=\"actions && actions.length !== 0\"\n    align=\"end\"\n  >\n    <ng-container *ngFor=\"let item of actions\">\n      <ng-container>\n        <narik-button\n          cssClass=\"btn-sm\"\n          [attr.narik-form-item-key]=\"item.dialogResult\"\n          class=\"mr-2\"\n          (nClick)=\"actionClick(item)\"\n          [color]=\"item.color\"\n          [icon]=\"item.icon\"\n          label=\"{{ 'dialog-buttons.' + item.label | translate }}\"\n        ></narik-button>\n      </ng-container>\n    </ng-container>\n  </div>\n</div>\n", styles: [".dialog-container{background-color:#fff;border-radius:5px;box-shadow:20px 20px 15px -7px #0003,0 24px 38px 3px #00000024,0 9px 46px 8px #0000001f}\n"] }]
        }] });

class NarikNgbInputDialog {
    constructor(parameters) {
        this.entity = {};
        this.fields = [];
        if (parameters) {
            this.entity = parameters.entity;
            this.fields = parameters.fields;
        }
    }
    ngOnInit() { }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbInputDialog.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbInputDialog, deps: [{ token: PARAMETERS }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbInputDialog.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbInputDialog, selector: "ng-component", ngImport: i0, template: "<div class=\"pr-2 pl-2\">\n  <narik-dynamic-form [model]=\"entity\" [fields]=\"fields\"></narik-dynamic-form>\n</div>\n", components: [{ type: NarikNgbDynamicForm, selector: "narik-dynamic-form , narik-ngb-dynamic-form" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbInputDialog, decorators: [{
            type: Component,
            args: [{ template: "<div class=\"pr-2 pl-2\">\n  <narik-dynamic-form [model]=\"entity\" [fields]=\"fields\"></narik-dynamic-form>\n</div>\n" }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [PARAMETERS]
                }] }]; } });

class NarikNgbMessageDialog {
    constructor(parameters) {
        if (parameters) {
            this.message = parameters.message;
        }
    }
    ngOnInit() { }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbMessageDialog.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbMessageDialog, deps: [{ token: PARAMETERS }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbMessageDialog.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbMessageDialog, selector: "ng-component", ngImport: i0, template: "<div class=\"message-container\">{{message | translate}}</div>\n", styles: [""], pipes: { "translate": i4.TranslatePipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbMessageDialog, decorators: [{
            type: Component,
            args: [{ template: "<div class=\"message-container\">{{message | translate}}</div>\n", styles: [""] }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [PARAMETERS]
                }] }]; } });

class NarikNgbDialogModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbDialogModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDialogModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbDialogModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDialogModule, declarations: [NarikNgbDialogContainer,
        NarikNgbInputDialog,
        NarikNgbMessageDialog], imports: [CommonModule,
        FormsModule,
        TranslateModule,
        NarikCommonModule,
        NarikNgbButtonModule,
        NarikNgbDynamicFormModule], exports: [NarikNgbDialogContainer,
        NarikNgbInputDialog,
        NarikNgbMessageDialog] });
/** @nocollapse */ /** @nocollapse */ NarikNgbDialogModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDialogModule, providers: [
        {
            provide: DIALOG_CONTAINER,
            useValue: NarikNgbDialogContainer,
        },
        {
            provide: DIALOG_MESSAGE_COMPONENT,
            useValue: NarikNgbMessageDialog,
        },
        {
            provide: DIALOG_INPUT_COMPONENT,
            useValue: NarikNgbInputDialog,
        },
    ], imports: [[
            CommonModule,
            FormsModule,
            TranslateModule,
            NarikCommonModule,
            NarikNgbButtonModule,
            NarikNgbDynamicFormModule,
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbDialogModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        FormsModule,
                        TranslateModule,
                        NarikCommonModule,
                        NarikNgbButtonModule,
                        NarikNgbDynamicFormModule,
                    ],
                    declarations: [
                        NarikNgbDialogContainer,
                        NarikNgbInputDialog,
                        NarikNgbMessageDialog,
                    ],
                    exports: [
                        NarikNgbDialogContainer,
                        NarikNgbInputDialog,
                        NarikNgbMessageDialog,
                    ],
                    providers: [
                        {
                            provide: DIALOG_CONTAINER,
                            useValue: NarikNgbDialogContainer,
                        },
                        {
                            provide: DIALOG_MESSAGE_COMPONENT,
                            useValue: NarikNgbMessageDialog,
                        },
                        {
                            provide: DIALOG_INPUT_COMPONENT,
                            useValue: NarikNgbInputDialog,
                        },
                    ],
                    entryComponents: [
                        NarikNgbDialogContainer,
                        NarikNgbInputDialog,
                        NarikNgbMessageDialog,
                    ],
                }]
        }] });

class NarikNgbTreeview extends NarikTreeview {
    constructor(injector) {
        super(injector);
    }
    set selectedItem(value) {
        this._selectedItem = value;
    }
    get selectedItem() {
        return this._selectedItem;
    }
    addNode(selectedNode) {
        throw new Error('Method not implemented.');
    }
    deleteNode(selectedNode) {
        throw new Error('Method not implemented.');
    }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbTreeview.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbTreeview, deps: [{ token: i0.Injector }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbTreeview.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbTreeview, selector: "narik-ngb-treeview narik-treeview", inputs: { newNodeTitle: "newNodeTitle" }, usesInheritance: true, ngImport: i0, template: "" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbTreeview, decorators: [{
            type: Component,
            args: [{ selector: 'narik-ngb-treeview narik-treeview', template: "" }]
        }], ctorParameters: function () { return [{ type: i0.Injector }]; }, propDecorators: { newNodeTitle: [{
                type: Input
            }] } });

class NarikNgbToolBar extends NarikToolBar {
    constructor(injector, viewContainerRef) {
        super(injector, viewContainerRef);
        this.uniqueId = '';
        this.toolbarItems = [];
        this.uniqueId = 'toolbar' + UUID.UUID();
    }
    ngOnInit() {
        super.ngOnInit();
        let isnewGroup = false;
        let toolBarGroup = [];
        for (const item of this.items) {
            if (item.itemType === 'divider') {
                isnewGroup = true;
            }
            if (item.itemType !== 'divider') {
                toolBarGroup.push(item);
            }
            if (isnewGroup) {
                this.toolbarItems.push([...toolBarGroup]);
                toolBarGroup = [];
            }
            isnewGroup = false;
        }
        if (toolBarGroup.length !== 0) {
            this.toolbarItems.push(toolBarGroup);
        }
        for (const group of this.toolbarItems) {
            let index = 0;
            for (const item of group) {
                let cssClass = '';
                if (index !== 0) {
                    cssClass += ' btn-not-first-child';
                }
                if (index !== group.length - 1) {
                    cssClass += ' btn-not-last-child';
                }
                item.cssClass = (item.cssClass || '') + cssClass;
                index++;
            }
        }
    }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbToolBar.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbToolBar, deps: [{ token: i0.Injector }, { token: i0.ViewContainerRef }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbToolBar.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbToolBar, selector: "narik-toolbar , narik-ngb-toolbar", usesInheritance: true, ngImport: i0, template: "<div class=\"btn-toolbar\" role=\"toolbar\" aria-label=\"Toolbar with button groups\">\n  <div class=\"btn-group mr-1\" *ngFor=\"let group of toolbarItems\">\n    <ng-container *ngFor=\"let item of group; let i = index\">\n      <ng-container *ngIf=\"item.itemType === 'button'\">\n        <narik-button\n          class=\"toolbar-btn\"\n          *ngIf=\"!item.hideExpr || !invisibleItems[item.key]\"\n          [disable]=\"item.disableExpr && disableItems[item.key]\"\n          [isBusy]=\"item.busyExpr && busyItems[item.key]\"\n          [cssClass]=\"item.cssClass\"\n          (nClick)=\"itemCommand(item)\"\n          [buttonStyle]=\"'secondary'\"\n          [icon]=\"item.icon\"\n          ngbTooltip=\"{{\n            (item.tooltip ? (item.tooltip | translate) : '') +\n              (options.appendShortcutToTooltip && item.shortcut\n                ? '(' + (item.shortcut | shortcut) + ')'\n                : '')\n          }}\"\n          container=\"body\"\n          [label]=\"showLabel ? item.label : ''\"\n        ></narik-button>\n      </ng-container>\n    </ng-container>\n  </div>\n</div>\n", components: [{ type: NarikNgbButtonComponent, selector: "narik-ngb-button , narik-button " }], directives: [{ type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i1$1.NgbTooltip, selector: "[ngbTooltip]", inputs: ["animation", "autoClose", "placement", "triggers", "container", "disableTooltip", "tooltipClass", "openDelay", "closeDelay", "ngbTooltip"], outputs: ["shown", "hidden"], exportAs: ["ngbTooltip"] }], pipes: { "translate": i4.TranslatePipe, "shortcut": i9.ShortcutPipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbToolBar, decorators: [{
            type: Component,
            args: [{ selector: 'narik-toolbar , narik-ngb-toolbar', template: "<div class=\"btn-toolbar\" role=\"toolbar\" aria-label=\"Toolbar with button groups\">\n  <div class=\"btn-group mr-1\" *ngFor=\"let group of toolbarItems\">\n    <ng-container *ngFor=\"let item of group; let i = index\">\n      <ng-container *ngIf=\"item.itemType === 'button'\">\n        <narik-button\n          class=\"toolbar-btn\"\n          *ngIf=\"!item.hideExpr || !invisibleItems[item.key]\"\n          [disable]=\"item.disableExpr && disableItems[item.key]\"\n          [isBusy]=\"item.busyExpr && busyItems[item.key]\"\n          [cssClass]=\"item.cssClass\"\n          (nClick)=\"itemCommand(item)\"\n          [buttonStyle]=\"'secondary'\"\n          [icon]=\"item.icon\"\n          ngbTooltip=\"{{\n            (item.tooltip ? (item.tooltip | translate) : '') +\n              (options.appendShortcutToTooltip && item.shortcut\n                ? '(' + (item.shortcut | shortcut) + ')'\n                : '')\n          }}\"\n          container=\"body\"\n          [label]=\"showLabel ? item.label : ''\"\n        ></narik-button>\n      </ng-container>\n    </ng-container>\n  </div>\n</div>\n" }]
        }], ctorParameters: function () { return [{ type: i0.Injector }, { type: i0.ViewContainerRef }]; } });

class NarikNgbToolbarModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbToolbarModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbToolbarModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbToolbarModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbToolbarModule, declarations: [NarikNgbToolBar], imports: [CommonModule,
        FormsModule,
        NarikNgbButtonModule,
        TranslateModule,
        NgbTooltipModule,
        NarikCommonModule], exports: [NarikNgbToolBar] });
/** @nocollapse */ /** @nocollapse */ NarikNgbToolbarModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbToolbarModule, providers: [], imports: [[
            CommonModule,
            FormsModule,
            NarikNgbButtonModule,
            TranslateModule,
            NgbTooltipModule,
            NarikCommonModule,
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbToolbarModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        FormsModule,
                        NarikNgbButtonModule,
                        TranslateModule,
                        NgbTooltipModule,
                        NarikCommonModule,
                    ],
                    declarations: [NarikNgbToolBar],
                    exports: [NarikNgbToolBar],
                    providers: [],
                }]
        }] });

class NarikNgbTreeviewModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbTreeviewModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbTreeviewModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbTreeviewModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbTreeviewModule, declarations: [NarikNgbTreeview], imports: [CommonModule,
        FormsModule,
        NarikNgbToolbarModule,
        TranslateModule], exports: [NarikNgbTreeview] });
/** @nocollapse */ /** @nocollapse */ NarikNgbTreeviewModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbTreeviewModule, providers: [], imports: [[
            CommonModule,
            FormsModule,
            NarikNgbToolbarModule,
            TranslateModule,
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbTreeviewModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        FormsModule,
                        NarikNgbToolbarModule,
                        TranslateModule,
                    ],
                    declarations: [NarikNgbTreeview],
                    exports: [NarikNgbTreeview],
                    providers: [],
                }]
        }] });

class NarikNgbCoreModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbCoreModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCoreModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbCoreModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCoreModule, imports: [CommonModule] });
/** @nocollapse */ /** @nocollapse */ NarikNgbCoreModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCoreModule, providers: [], imports: [[CommonModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbCoreModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule],
                    declarations: [],
                    exports: [],
                    providers: [],
                }]
        }] });

class NarikNgbTabOutlet extends NarikTabOutlet {
    constructor(injector, zone) {
        super(injector);
        this.zone = zone;
    }
    removeTabItem(index) {
        this.removeTab(index);
        return false;
    }
    addView(tab) {
        super.addView(tab);
        this.zone.onStable
            .pipe(take(1))
            .subscribe(() => this.navElement.select(tab.uniqueId));
    }
}
/** @nocollapse */ /** @nocollapse */ NarikNgbTabOutlet.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbTabOutlet, deps: [{ token: i0.Injector }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ /** @nocollapse */ NarikNgbTabOutlet.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.1", type: NarikNgbTabOutlet, selector: "narik-ngb-tab-outlet , narik-tab-outlet", viewQueries: [{ propertyName: "navElement", first: true, predicate: ["nav"], descendants: true, static: true }], usesInheritance: true, ngImport: i0, template: "<div>\n  <nav ngbNav #nav=\"ngbNav\" [destroyOnHide]=\"false\" class=\"nav-tabs\">\n    <ng-container\n      ngbNavItem=\"tab.uniqueId\"\n      *ngFor=\"let tab of tabs; let index = index; trackBy: trackByFn\"\n    >\n      <ng-template ngbNavContent>\n        <div class=\"p-1\">\n          <ng-container *ngIf=\"tab.component\">\n            <ng-container\n              *narikComponentLoader=\"\n                tab.component;\n                parameters: tab.data;\n                providers: tab.providers\n              \"\n            ></ng-container>\n          </ng-container>\n        </div>\n      </ng-template>\n      <ng-template ngbNavLink>\n        <div class=\"title-container\">\n          <span>{{ tab.title | translate }}</span>\n          <i (click)=\"removeTabItem(index)\" class=\"fas fa-times close-btn ml-2\">\n          </i>\n        </div>\n      </ng-template>\n    </ng-container>\n  </nav>\n</div>\n", styles: [".close-btn{color:red;cursor:pointer}.title-container{display:\"flex\";justify-content:space-between}\n"], directives: [{ type: i1$1.NgbNav, selector: "[ngbNav]", inputs: ["animation", "destroyOnHide", "orientation", "roles", "keyboard", "activeId"], outputs: ["activeIdChange", "shown", "hidden", "navChange"], exportAs: ["ngbNav"] }, { type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i1$1.NgbNavItem, selector: "[ngbNavItem]", inputs: ["disabled", "domId", "destroyOnHide", "ngbNavItem"], outputs: ["shown", "hidden"], exportAs: ["ngbNavItem"] }, { type: i1$1.NgbNavContent, selector: "ng-template[ngbNavContent]" }, { type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i9.NarikComponentLoaderDirective, selector: "[narikComponentLoader]", inputs: ["narikComponentLoader", "narikComponentLoaderParameters", "narikComponentLoaderBindings", "narikComponentLoaderBindingSource", "narikComponentLoaderProviders", "narikComponentLoaderEvents"] }], pipes: { "translate": i4.TranslatePipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbTabOutlet, decorators: [{
            type: Component,
            args: [{ selector: 'narik-ngb-tab-outlet , narik-tab-outlet', template: "<div>\n  <nav ngbNav #nav=\"ngbNav\" [destroyOnHide]=\"false\" class=\"nav-tabs\">\n    <ng-container\n      ngbNavItem=\"tab.uniqueId\"\n      *ngFor=\"let tab of tabs; let index = index; trackBy: trackByFn\"\n    >\n      <ng-template ngbNavContent>\n        <div class=\"p-1\">\n          <ng-container *ngIf=\"tab.component\">\n            <ng-container\n              *narikComponentLoader=\"\n                tab.component;\n                parameters: tab.data;\n                providers: tab.providers\n              \"\n            ></ng-container>\n          </ng-container>\n        </div>\n      </ng-template>\n      <ng-template ngbNavLink>\n        <div class=\"title-container\">\n          <span>{{ tab.title | translate }}</span>\n          <i (click)=\"removeTabItem(index)\" class=\"fas fa-times close-btn ml-2\">\n          </i>\n        </div>\n      </ng-template>\n    </ng-container>\n  </nav>\n</div>\n", styles: [".close-btn{color:red;cursor:pointer}.title-container{display:\"flex\";justify-content:space-between}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.Injector }, { type: i0.NgZone }]; }, propDecorators: { navElement: [{
                type: ViewChild,
                args: ['nav', { static: true }]
            }] } });

class NarikNgbTabOutletModule {
}
/** @nocollapse */ /** @nocollapse */ NarikNgbTabOutletModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbTabOutletModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikNgbTabOutletModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbTabOutletModule, declarations: [NarikNgbTabOutlet], imports: [CommonModule, TranslateModule, NarikCommonModule, NgbNavModule], exports: [NarikNgbTabOutlet] });
/** @nocollapse */ /** @nocollapse */ NarikNgbTabOutletModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbTabOutletModule, providers: [], imports: [[CommonModule, TranslateModule, NarikCommonModule, NgbNavModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikNgbTabOutletModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, TranslateModule, NarikCommonModule, NgbNavModule],
                    declarations: [NarikNgbTabOutlet],
                    exports: [NarikNgbTabOutlet],
                    providers: [],
                }]
        }] });

class NarikUiNgBootstrapModule {
}
/** @nocollapse */ /** @nocollapse */ NarikUiNgBootstrapModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikUiNgBootstrapModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ /** @nocollapse */ NarikUiNgBootstrapModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikUiNgBootstrapModule, imports: [TranslateModule,
        NarikNgbAutoCompleteModule,
        NarikNgbBusyIndicatorModule,
        NarikNgbButtonModule,
        NarikNgbCheckBoxModule,
        NarikNgbCheckBoxListModule,
        NarikNgbDataTableModule,
        NarikNgbDatePickerModule,
        NarikNgbDialogModule,
        NarikNgbDynamicFormModule,
        NarikNgbInputModule,
        NarikNgbRadioGroupModule,
        NarikNgbSelectModule,
        NarikNgbToolbarModule,
        NarikNgbTreeviewModule,
        NarikNgbCoreModule,
        NarikNgbTabOutletModule], exports: [TranslateModule,
        NarikNgbAutoCompleteModule,
        NarikNgbBusyIndicatorModule,
        NarikNgbButtonModule,
        NarikNgbCheckBoxModule,
        NarikNgbCheckBoxListModule,
        NarikNgbDataTableModule,
        NarikNgbDatePickerModule,
        NarikNgbDialogModule,
        NarikNgbDynamicFormModule,
        NarikNgbInputModule,
        NarikNgbRadioGroupModule,
        NarikNgbSelectModule,
        NarikNgbToolbarModule,
        NarikNgbTreeviewModule,
        NarikNgbCoreModule,
        NarikNgbTabOutletModule] });
/** @nocollapse */ /** @nocollapse */ NarikUiNgBootstrapModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikUiNgBootstrapModule, providers: [], imports: [[
            TranslateModule,
            NarikNgbAutoCompleteModule,
            NarikNgbBusyIndicatorModule,
            NarikNgbButtonModule,
            NarikNgbCheckBoxModule,
            NarikNgbCheckBoxListModule,
            NarikNgbDataTableModule,
            NarikNgbDatePickerModule,
            NarikNgbDialogModule,
            NarikNgbDynamicFormModule,
            NarikNgbInputModule,
            NarikNgbRadioGroupModule,
            NarikNgbSelectModule,
            NarikNgbToolbarModule,
            NarikNgbTreeviewModule,
            NarikNgbCoreModule,
            NarikNgbTabOutletModule,
        ], TranslateModule,
        NarikNgbAutoCompleteModule,
        NarikNgbBusyIndicatorModule,
        NarikNgbButtonModule,
        NarikNgbCheckBoxModule,
        NarikNgbCheckBoxListModule,
        NarikNgbDataTableModule,
        NarikNgbDatePickerModule,
        NarikNgbDialogModule,
        NarikNgbDynamicFormModule,
        NarikNgbInputModule,
        NarikNgbRadioGroupModule,
        NarikNgbSelectModule,
        NarikNgbToolbarModule,
        NarikNgbTreeviewModule,
        NarikNgbCoreModule,
        NarikNgbTabOutletModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikUiNgBootstrapModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        TranslateModule,
                        NarikNgbAutoCompleteModule,
                        NarikNgbBusyIndicatorModule,
                        NarikNgbButtonModule,
                        NarikNgbCheckBoxModule,
                        NarikNgbCheckBoxListModule,
                        NarikNgbDataTableModule,
                        NarikNgbDatePickerModule,
                        NarikNgbDialogModule,
                        NarikNgbDynamicFormModule,
                        NarikNgbInputModule,
                        NarikNgbRadioGroupModule,
                        NarikNgbSelectModule,
                        NarikNgbToolbarModule,
                        NarikNgbTreeviewModule,
                        NarikNgbCoreModule,
                        NarikNgbTabOutletModule,
                    ],
                    declarations: [],
                    exports: [
                        TranslateModule,
                        NarikNgbAutoCompleteModule,
                        NarikNgbBusyIndicatorModule,
                        NarikNgbButtonModule,
                        NarikNgbCheckBoxModule,
                        NarikNgbCheckBoxListModule,
                        NarikNgbDataTableModule,
                        NarikNgbDatePickerModule,
                        NarikNgbDialogModule,
                        NarikNgbDynamicFormModule,
                        NarikNgbInputModule,
                        NarikNgbRadioGroupModule,
                        NarikNgbSelectModule,
                        NarikNgbToolbarModule,
                        NarikNgbTreeviewModule,
                        NarikNgbCoreModule,
                        NarikNgbTabOutletModule,
                    ],
                    providers: [],
                }]
        }] });

class NarikUiListForm extends NarikListForm {
    constructor(injector) {
        super(injector);
        this.ds = [];
        this.hasDataSource = false;
    }
    get isServerSide() {
        return this.config && this.config.isServerSideData ? true : false;
    }
    ngOnInit() {
        super.ngOnInit();
        if (this.fields) {
        }
        if (this.config) {
            if (this.isServerSide) {
                const that = this;
            }
        }
    }
    ngAfterViewInit() { }
    useData(result) {
        this.dataSource = result.data;
    }
    refresh(remoteDaraParams) {
        if (!this.isServerSide) {
            this.getEntities();
        }
        else {
        }
    }
}
/** @nocollapse */ /** @nocollapse */ NarikUiListForm.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikUiListForm, deps: [{ token: i0.Injector }], target: i0.ɵɵFactoryTarget.Directive });
/** @nocollapse */ /** @nocollapse */ NarikUiListForm.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.0.1", type: NarikUiListForm, usesInheritance: true, ngImport: i0 });
__decorate([
    NarikInject(TranslateService),
    __metadata("design:type", TranslateService)
], NarikUiListForm.prototype, "translateService", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.1", ngImport: i0, type: NarikUiListForm, decorators: [{
            type: Directive
        }], ctorParameters: function () { return [{ type: i0.Injector }]; }, propDecorators: { translateService: [] } });

class NarikUiEditForm extends NarikEditForm {
    constructor(injector) {
        super(injector);
    }
    submit() {
        if (this.formElement) {
            this.renderer.addClass(this.formElement.nativeElement, 'was-validated');
        }
        super.submit();
    }
}
__decorate([
    NarikInject(Renderer2),
    __metadata("design:type", Renderer2)
], NarikUiEditForm.prototype, "renderer", void 0);

/*
 * Public API Surface of narik-ui-ng-bootstrap
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NarikNgbAutoComplete, NarikNgbAutoCompleteModule, NarikNgbBusyIndicator, NarikNgbBusyIndicatorModule, NarikNgbButtonComponent, NarikNgbButtonModule, NarikNgbCheckBox, NarikNgbCheckBoxList, NarikNgbCheckBoxListModule, NarikNgbCheckBoxModule, NarikNgbCoreModule, NarikNgbDataTable, NarikNgbDataTableModule, NarikNgbDatePicker, NarikNgbDatePickerModule, NarikNgbDialogContainer, NarikNgbDialogModule, NarikNgbDynamicForm, NarikNgbDynamicFormModule, NarikNgbInput, NarikNgbInputDialog, NarikNgbInputModule, NarikNgbMessageDialog, NarikNgbRadioGroup, NarikNgbRadioGroupModule, NarikNgbSelect, NarikNgbSelectModule, NarikNgbTabOutlet, NarikNgbTabOutletModule, NarikNgbToolBar, NarikNgbToolbarModule, NarikNgbTreeview, NarikNgbTreeviewModule, NarikUiEditForm, NarikUiListForm, NarikUiNgBootstrapModule };
